@@ -476,14 +476,8 @@ static void ahp_serial_flushRXTX()
 
 #endif
 
-static int ahp_serial_OpenComport(const char* devname)
+static int ahp_serial_OpenComport(const char* dev_name)
 {
-    char dev_name[128];
-#ifndef WINDOWS
-    sprintf(dev_name, "/dev/%s", devname);
-#else
-    sprintf(dev_name, "\\\\.\\%s", devname);
-#endif
     if(ahp_serial_fd == -1)
         ahp_serial_fd = open(dev_name, O_RDWR);
 
@@ -528,7 +522,7 @@ static int ahp_serial_RecvBuf(unsigned char *buf, int size)
 {
     int n = -ENODEV;
     int nbytes = 0;
-    int ntries = size*2;
+    int ntries = size;
     int bytes_left = size;
     int err = 0;
     if(ahp_serial_mutexes_initialized) {
@@ -537,7 +531,7 @@ static int ahp_serial_RecvBuf(unsigned char *buf, int size)
         while(bytes_left > 0 && ntries-->0) {
             usleep(12000000/ahp_serial_baudrate);
             n = read(ahp_serial_fd, buf+nbytes, bytes_left);
-            if(n<1) {
+            if(n<0) {
                 err = -errno;
                 continue;
             }
@@ -546,8 +540,11 @@ static int ahp_serial_RecvBuf(unsigned char *buf, int size)
         }
         pthread_mutex_unlock(&ahp_serial_mutex);
     }
-    if(nbytes < size)
+    if(nbytes < 1) {
+        if(ntries < 0)
+            return -ENODATA;
         return err;
+    }
     return nbytes;
 }
 
@@ -606,10 +603,7 @@ static int ahp_serial_AlignFrame(int sof, int maxtries)
     while(c != sof && (maxtries > 0 ? maxtries-- > 0 : 1)) {
         c = ahp_serial_RecvByte();
         if(c < 0) {
-          if(errno == EAGAIN)
-              continue;
-          else
-              return errno;
+            continue;
         }
     }
     return 0;
